@@ -1,7 +1,7 @@
 /*
  * paths.h	Paths of files that init and related utilities need.
  *
- * Version:	@(#) paths.h 2.84 27-Nov-2001
+ * Version:	@(#) paths.h 2.85-8 05-Nov-2003
  *
  * Author:	Miquel van Smoorenburg, <miquels@cistron.nl>
  *
@@ -13,10 +13,6 @@
  *		as published by the Free Software Foundation; either version
  *		2 of the License, or (at your option) any later version.
  */
-#define INITLVL		"/etc/initrunlvl"	/* COMPAT: New runlevel */
-#define INITLVL2	"/var/log/initrunlvl"	/* COMPAT: New runlevel */
-				/* Note: INITLVL2 definition needs INITLVL */
-#define PWRSTAT		"/etc/powerstatus"	/* COMPAT: SIGPWR reason (OK/BAD) */
 #define VT_MASTER	"/dev/tty0"		/* Virtual console master */
 #define CONSOLE		"/dev/console"		/* Logical system console */
 #define SECURETTY	"/etc/securetty"	/* List of root terminals */
@@ -27,12 +23,18 @@
 #define FASTBOOT	"/fastboot"		/* Enable fast boot. */
 #define FORCEFSCK	"/forcefsck"		/* Force fsck on boot */
 #define SDPID		"/var/run/shutdown.pid"	/* PID of shutdown program */
-#define IOSAVE		"/etc/ioctl.save"	/* termios settings for SU */
 #define SHELL		"/bin/sh"		/* Default shell */
+#define SULOGIN		"/sbin/sulogin"		/* Sulogin */
 #define INITSCRIPT	"/etc/initscript"	/* Initscript. */
+#define PWRSTAT		"/etc/powerstatus"	/* COMPAT: SIGPWR reason (OK/BAD) */
+
 #if 0
+#define INITLVL		"/etc/initrunlvl"	/* COMPAT: New runlevel */
+#define INITLVL2	"/var/log/initrunlvl"	/* COMPAT: New runlevel */
+				/* Note: INITLVL2 definition needs INITLVL */
 #define HALTSCRIPT1	"/etc/init.d/halt"	/* Called by "fast" shutdown */
 #define HALTSCRIPT2	"/etc/rc.d/rc.0"	/* Called by "fast" shutdown */
 #define REBOOTSCRIPT1	"/etc/init.d/reboot"	/* Ditto. */
 #define REBOOTSCRIPT2	"/etc/rc.d/rc.6"	/* Ditto. */
 #endif
+
